@@ -100,9 +100,8 @@ def 官网存活性检测(官网地址: str = "http://www.baidu.com", 测试时
     return True
 
 
-报警器 = False
-
 
+递归更新次数=0
 def Fishconsole_Update():
     # 你要删我也没办法，反正如果出了什么错过了重大更新你就自己乐呵去呗
     # 这个不是模块，我们将会在导入该模块的时候顺序执行此处
@@ -111,7 +110,15 @@ def Fishconsole_Update():
     # 强制更新系统执行组一期
 
     # 判断设备是否接入网络
-    global 报警器, 开始时间, 结束时间, day, month
+
+    import pkg_resources #检查版本号的
+    global 开始时间, 结束时间, day, month,递归更新次数
+
+
+    递归更新次数 = 递归更新次数 + 1
+    if 递归更新次数 > 4:
+        print(logs.日志("强制更新系统更新时出现故障，强制更新退出，这个问题应该是本地版本号和云控版本号和包管理器的版本号对不上所造成的", "红色"))
+        logs.安全退出("")
 
     def isConnected():
         import requests
@@ -119,8 +126,6 @@ def Fishconsole_Update():
         try:
             requests.get("https://pypi.org/project/Fishconsole/", timeout=7)
         except:
-            global 报警器
-            报警器 = True
             print(logs.日志("》强制更新系统》isConnected》官网连接失败"))
 
             return False
@@ -251,16 +256,23 @@ def Fishconsole_Update():
             结束时间 = datetime.datetime(年, 月, 日)
             开始时间 = datetime.datetime(上一年, 上一月, 上一日)
         except ValueError:
-            报警器 = True
             logs.安全退出("强制更新系统》缓存文件遭到非法修改")
         经过时间 = (结束时间 - 开始时间).days
         if 经过时间 >= 5:
-            config["updata"] = True
-            config["year"] = 年
-            config["month"] = 月
-            config["day"] = 日
-            files.缓存(1, config)
-            报警器 = True
+            res = 讯飞云控("2fqV7")["updata"]
+            if res:
+                config["updata"] = True
+                config["year"] = 年
+                config["month"] = 月
+                config["day"] = 日
+                files.缓存(1, config)
+            else:
+                config["year"] = 年
+                config["month"] = 月
+                config["day"] = 日
+                print(logs.日志("强制更新系统》自动更新》云控已取消本次更新，检查点重置","紫色"))
+                files.缓存(1, config)
+            logs.变量查看("res",res)
             print(logs.日志("强制更新系统》自动更新》Fishconsole Project自动更新已对您设备上的Fishconsole进行了例行的更新检查", "红色"))
 
             # updata在前面的参数提取中搞就已经好了，现在我们只需要执行操作了
@@ -276,6 +288,17 @@ def Fishconsole_Update():
                 files.缓存(1, config)
                 if res:
                     # 返回值不是False，就说明官网存活，也说明我们链接上了官网
+
+                    res = 讯飞云控("2fqV7")["updata"]
+                    if not res:
+                        print(logs.日志("强制更新系统》自动更新》云控已取消本次更新,检查点重置", "紫色"))
+                        config["year"] = 年
+                        config["month"] = 月
+                        config["day"] = 日
+                        config["updata"] = False
+                        files.缓存(1, config)
+                        logs.安全退出("")
+
                     print(logs.日志(f"》Fishconsole强制更新系统{fcv.version()}》Fishsys 》您的版本过低，我们将尝试自动为您更新", "红色"))
                     # 最原始的操作，大家引以为戒
                     # os.remove("Fishconsole.fcc")
@@ -285,12 +308,10 @@ def Fishconsole_Update():
                         os.system(f'pip install --upgrade Fishconsole')
                         main(['install', '--upgrade', 'Fishconsole'])
                     except:
-                        报警器 = True
                         logs.日志("强制更新系统》pip命令组出现未知错误，程序强制退出", "红色")
-                    报警器 = True
-                    logs.日志("强制更新系统》更新完毕，请重新运行", "红色")
+
+                    Fishconsole_Update()
                 else:
-                    报警器 = True
                     logs.日志("强制更新系统》官网链接失败", "红色")
 
             else:
@@ -319,9 +340,15 @@ def Fishconsole_Update():
                 isConnected = 官网存活性检测("https://pypi.org/project/Fishconsole/")
                 if Forcedupdate:
                     if isConnected:
-                        系统日志(f"检测到网络连接成功", "强制更新系统help", UPI)
+
+                        import imp
+                        imp.reload(pkg_resources)
+                        imp.reload(fcv)
+
+
+                        系统日志(f"检测到网络连接成功", "强制更新系统", UPI)
                         print(logs.日志(f"Fishconsole{fcv.version()} 检查更新开始。。。"))
-                        v = fcv.version()
+                        v = pkg_resources.get_distribution('Fishconsole').version
                         res_v = requests.get("https://pypi.org/project/Fishconsole/", timeout=7).text
                         res_v = re.findall('<h1 class="package-header__name">\n        (.*)\n      </h1>', res_v)[0].split(" ")[1]
 
@@ -329,9 +356,14 @@ def Fishconsole_Update():
                         系统日志(f"v is {v}", "强制更新系统help", UPI)
                         # 开启了强制更新系统
 
+
+
+
+
+
                         if res_v == v:
                             print(logs.日志(f"Fishconsole{fcv.version()} 检查更新结束,您的模块为最新版本", "绿色"))
-                            print(logs.日志(f"Fishconsole{fcv.version()} 已解锁，您可以使用了", "绿色"))
+                            print(logs.日志(f"Fishconsole{fcv.version()} 强制更新系统暂时关闭，重新启动的时间为5天以后，如果需要手动触发更新，请使用fcv.fdebug中的updata指令", "绿色"))
                             files.缓存(3, {'FHUM': True})
 
                             def 帮助():
@@ -362,16 +394,15 @@ def Fishconsole_Update():
                             # 尝试获取缓存中的值
 
                             # 这是没有检查到值或者发现时执行的操作
-                            print(logs.日志(f"检测到最新版本号发生了变化({res_v}>{v})，缓存刷新，我们将在下一次启动程序时自动更新", "红色"))
+                            print(logs.日志(f"检测到最新版本号发生了变化({res_v}>{v})，我们将开始自动更新", "红色"))
                             config = files.缓存(2)
                             系统日志(f"config is {config}", "强制更新系统help", UPI)
                             config["updata"] = True
                             files.缓存(1, config)
-                            报警器 = True
-                            print(logs.日志(f"Fishconsole 》强制更新启动", "红色"))
+                            Fishconsole_Update()
+
                     else:
                         print(logs.日志(f"Fishconsole{fcv.version()} 检查更新结束"))
-                        报警器 = True
                         print(logs.日志(f"Fishconsole 》你的设备无法访问互联网，请检查网络连接", "红色"))
                 else:
                     print(logs.日志(f"Fishconsole{fcv.version()} 开发者您好,我们已经停止了强制更新。请注意，全局配置已重置", "绿色"))
@@ -430,13 +461,11 @@ def passwordsys(模式: any, id_protect: str, password_a: str):
             res_a = res_a + a
             if a == "@":
                 print(logs.颜色(logs.日志(""), 色选="红色"))
-                报警器 = True
                 logs.安全退出("你的密码中不允许有@符号，请重新输入")
 
         for b in id_protect:
             res_b = res_b + b
             if b == "@":
-                报警器 = True
                 logs.安全退出(logs.日志("你的原文中不允许有@符号，请重新输入", 色选="红色"))
 
         else:
@@ -989,9 +1018,8 @@ def 讯飞云控(fid):
     :return: 字典或列表
     """
     global res
-    import json
     import requests
-    import chardet
+
     if 官网存活性检测("https://iflynote.com/i/"):
         fid = str(fid)
         url = f"https://api.iflynote.com/notes/share/doc/shareFileDetail?fid={fid}"
@@ -1081,7 +1109,7 @@ def 邮件发送(
             from_addr = 邮件发送账号  # 邮件发送账号
             to_addrs = 邮件接收账号  # 接收邮件账号
 
-            if 授权码 == None:
+            if 授权码 is None:
                 temp = files.缓存(2, 变量名="AC")
                 if temp == "error":
                     logs.安全退出("未指定授权码")
@@ -1089,7 +1117,7 @@ def 邮件发送(
                     print(logs.日志("Fishsys邮件发送》检测到预设的授权码，导入"))
                     授权码 = temp
 
-            if 邮件发送账号 == None:
+            if 邮件发送账号 is None:
                 temp = files.缓存(2, 变量名="FESA")
                 if temp == "error":
                     logs.安全退出("未指定邮件发送账号")
@@ -1097,7 +1125,7 @@ def 邮件发送(
                     print(logs.日志("Fishsys邮件发送》检测到预设的邮件发送账号，导入"))
                     from_addr = temp
 
-            if 发件人姓名 == None:
+            if 发件人姓名 is None:
                 temp = files.缓存(2, 变量名="Sender")
                 if temp == "error":
                     logs.安全退出("未指定发件人姓名")
@@ -1123,7 +1151,7 @@ def 邮件发送(
             message['To'] = Header(收件人姓名, 'utf-8')  # 收件人
             subject = 邮件标题
             message['Subject'] = Header(subject, 'utf-8')  # 邮件标题
-            if 附件地址 != None:
+            if 附件地址 is not None:
                 message.attach(TXT)
             message.attach(MIMEText(HTML正文内容, 'HTML', 'utf-8'))  # 把正文附在邮件上
             try:
