@@ -12,11 +12,11 @@ def version():
 
     ----
 
-    版本云控，这是一个不重要但又很重要的模块
+    版本云控，这是一个不重要但又很重要的模块，给setup用的
 
     :return: 返回版本号
     """
-    return '2.2.1'
+    return '2.2.10'
 
 
 def f_debug():
@@ -348,8 +348,10 @@ def f_debug():
 
 
         elif b[0] in ["version", "VERSION", "V", "v"]:
+            import Fishconsole
             print(logs.日志(f"Fishconsole fcv_debug [ 2.0 ]", "蓝色"))
-
+            print(logs.日志(f"Fishconsole版本：{Fishconsole.版本号()}","蓝色"))
+            print(logs.日志(f"制作者：鱼几斤","蓝色"))
 
         elif b[0] in ["pip", "PIP"]:
             未选触发器 = True
