@@ -12,10 +12,10 @@
 
 
 
-from Fishconsole import logs
+from Fishconsole import logs,Fishsys
 
 
-def 强制类型检测(任意变量, 预期类型):
+def 强制类型检测(任意变量, 预期类型:str):
     """
 
     Fishconsole files 强制类型检测
@@ -30,6 +30,11 @@ def 强制类型检测(任意变量, 预期类型):
     :param 预期类型: 你需要验证的类型比如a=1，强制类型检测（a,'int'）
     :return: bool
     """
+    type值 = str(type(预期类型))
+    变量类型 = type值.split("'")[1]
+    if 变量类型=="type":
+        logs.安全退出("强制类型检测》你必须指定str类型的预期类型")
+
     type值 = str(type(任意变量))
     变量类型 = type值.split("'")[1]
     if 变量类型 == 预期类型:
@@ -94,7 +99,7 @@ def 缓存(模式, 数据: dict = None, 文件名="Fishconsole.fcc",变量名=No
         a = 强制类型检测(数据, 'dict')
         if a:
                 数据 = str(数据)
-                数据 = bytes(数据, encoding="ASCII")
+                数据 = bytes(数据, encoding="utf-8")
                 with open(f'{文件名}', "wb") as file:
                     file.write(数据)
                     file.close()
@@ -106,7 +111,7 @@ def 缓存(模式, 数据: dict = None, 文件名="Fishconsole.fcc",变量名=No
             with open(f'{文件名}', "rb") as file:
                 a = file.read()
                 file.close()
-            解密 = str(a, encoding="ASCII")
+            解密 = str(a, encoding="utf-8")
             try:
                 解密 = eval(解密)
                 解密 = dict(解密)
@@ -137,7 +142,7 @@ def 缓存(模式, 数据: dict = None, 文件名="Fishconsole.fcc",变量名=No
             with open(f'{文件名}', "rb") as file:
                 a = file.read()
                 file.close()
-            解密 = str(a, encoding="ASCII")
+            解密 = str(a, encoding="utf-8")
             try:
                 解密 = eval(解密)
             except SyntaxError:
@@ -149,7 +154,7 @@ def 缓存(模式, 数据: dict = None, 文件名="Fishconsole.fcc",变量名=No
             if 强制类型检测(数据,"dict"):
                 解密=dict(解密,**数据)
                 数据 = str(解密)
-                数据 = bytes(数据, encoding="ASCII")
+                数据 = bytes(数据, encoding="utf-8")
                 with open(f'{文件名}', "wb") as file:
                     file.write(数据)
                     file.close()
