@@ -78,10 +78,10 @@ def 输入(text, 色选="红色"):
     :param 色选: 为指定的内容上色
     :return: 用户输入的值
     """
-    res = input(f"{颜色('O', f'{色选}')} 》{text}  {颜色('||》', 色选)}")
+    a="\033[1m" + "○"
+    res = input(f"{颜色(a, f'{色选}')} 》{text}  {颜色('||》', 色选)}")
     return res
 
-
 def 日志(text, 色选="Nona"):
     """
     FishConosle LOGS日志模块
